@@ -77,6 +77,10 @@ class SAMOutputRequest(OutputRequest):
                    'plane_of_array_irradiance': 'poa',
                    'gen_profiles': 'gen_profile',
                    'lcoe': 'lcoe_fcr',
+                   'foc': 'fixed_operating_cost',
+                   'voc': 'variable_operating_cost',
+                   'fcr': 'fixed_charge_rate',
+                   'cc': 'capital_cost',
                    'lcoe_nominal': 'lcoe_nom',
                    'real_lcoe': 'lcoe_real',
                    'net_present_value': 'project_return_aftertax_npv',
